@@ -26,3 +26,17 @@ def rng():
     return RelaxNG(
             reader(os.path.join(os.path.dirname(__file__),
                                 "standard/schema/cmi-customization.rng")))
+
+
+def validate(root):
+    """
+    validate XML data of given root against RNG schema
+    """
+    schema = rng()
+    result = schema.validate(root)
+    if result:
+        print("valid data in CMI format!")
+    else:
+        print("given data is invalid!")
+        print("error log:")
+        print(schema.error_log)
